@@ -57,12 +57,12 @@
 #' table <- getTransitionProbability(temporal_data, 
 #' cellid_column = "cell_id",time_column = "time_stamp")
 #' colnames(temporal_data) <- c("Cell.ID","t")
-#' ex_post_forecasting <- dataset[1800:1860,]
+#' ex_post_forecasting <- dataset[1830:1860,]
 #' ex_post <- msm(state_time_data = temporal_data,
 #'               forecast_type = "ex-post",
 #'               transition_probability_matrix = table,
 #'               initial_state = 2,
-#'               num_simulations = 10,
+#'               num_simulations = 2,
 #'               scoreHVT_results = scoring,
 #'               trainHVT_results = hvt.results,
 #'               actual_data = ex_post_forecasting,
@@ -261,6 +261,17 @@ msm <- function(state_time_data,
   has_full_transition_coverage <- all(scored_cells %in% transition_cells)
   
   # Determine n_ahead
+  if (forecast_type == "ex-ante") {
+    time_vals <- state_time_data[[time_column]]
+    time_step <- diff(time_vals)[1]
+    horizon_len <- if (length(n_ahead_ante) == 1) n_ahead_ante else length(n_ahead_ante)
+    n_ahead_ante <- seq(
+      from = max(time_vals) + time_step,
+      length.out = horizon_len,
+      by = time_step
+    )
+  }
+
   if (forecast_type == "ex-post") {
     if(!is.null(actual_data)) {
       n_ahead <- nrow(actual_data)
